==> vanilla-clipper-0.1.0.tgz: package/src/tempCodeRunnerFile.ts <==
// export const clip = async () => {
//     try {
//         const vBrowser = await VBrowser.launch(true)
//         const vPage = await vBrowser.newPage({})
//         for (const directory of [
//             'app',
//             'chrome',
//             'english',
//             'firebase',
//             'html',
//             'javascript',
//             'library',
//             'life',
//             'medical',
//             'reina',
//             'society',
//             'twitter-api',
//             'video',
//             'web-design',
//         ]) {
//             const fileList = (await readdir(`/mnt/g/clips/${directory}`)).filter(name =>
//                 name.endsWith('.html')
//             )
//             const successCount = await fileList.reduce(async (prevPromise, name, i) => {
//                 const old = await readFile(`/mnt/g/clips/${directory}/${name}`, 'utf8')
//                 const _successCount = await prevPromise
//                 const vMetadata = await VMetadata.parse(extractVanillaMetadata(old)!)
//                 sig.pending('[%d/%d] Cilpping %s', i + 1, fileList.length, vMetadata.url)
//                 try {
//                     await vPage.goto(vMetadata.url)
//                     const { html } = await vPage.clip({
//                         maxScrolls: 0,
//                     })
//                     const outputPath = `tmp/${directory}/${name}`
//                     await outputFile(outputPath, html)
//                     sig.success('Saved as %s', outputPath)
//                     return _successCount + 1
//                 } catch (error) {
//                     sig.error(error)
//                     return _successCount
//                 }
//             }, Promise.resolve(0))
//         }
//         await vPage.close()
//         await vBrowser.close()
//     } catch (error) {
//         sig.error(error)
//     } finally {
//         process.exit(0)
//     }
// }
// clip()
// import csstree from 'css-tree'

// const parsed = csstree.parse('@import url("s")')
// console.log(parsed)
import { readdirSync, statSync } from 'fs-extra'
import { ClipOptionsWithURL, VBrowser } from './core/VBrowser'

async function main() {
    const files = [] as ClipOptionsWithURL[]

    const dirs = readdirSync('/mnt/g/clips').filter(
        f => statSync('/mnt/g/clips/' + f).isDirectory() && f === 'life'
    )

    dirs.forEach(d => {
        files.push(
            ...readdirSync('/mnt/g/clips/' + d).map(f => ({
                url: `file:///g:/clips/${d}/${f}`,
                maxScrolls: 0,
                outputPath: `.vanilla-clipper/pages/main/${f}`,
            }))
        )
    })

    await VBrowser.clipPages({ noSandbox: true, headless: false }, files)
}

main()

==> vanilla-clipper-0.1.3.tgz: package/src/tempCodeRunnerFile.ts <==
// export const clip = async () => {
//     try {
//         const vBrowser = await VBrowser.launch(true)
//         const vPage = await vBrowser.newPage({})
//         for (const directory of [
//             'app',
//             'chrome',
//             'english',
//             'firebase',
//             'html',
//             'javascript',
//             'library',
//             'life',
//             'medical',
//             'reina',
//             'society',
//             'twitter-api',
//             'video',
//             'web-design',
//         ]) {
//             const fileList = (await readdir(`/mnt/g/clips/${directory}`)).filter(name =>
//                 name.endsWith('.html')
//             )
//             const successCount = await fileList.reduce(async (prevPromise, name, i) => {
//                 const old = await readFile(`/mnt/g/clips/${directory}/${name}`, 'utf8')
//                 const _successCount = await prevPromise
//                 const vMetadata = await VMetadata.parse(extractVanillaMetadata(old)!)
//                 sig.pending('[%d/%d] Cilpping %s', i + 1, fileList.length, vMetadata.url)
//                 try {
//                     await vPage.goto(vMetadata.url)
//                     const { html } = await vPage.clip({
//                         maxScrolls: 0,
//                     })
//                     const outputPath = `tmp/${directory}/${name}`
//                     await outputFile(outputPath, html)
//                     sig.success('Saved as %s', outputPath)
//                     return _successCount + 1
//                 } catch (error) {
//                     sig.error(error)
//                     return _successCount
//                 }
//             }, Promise.resolve(0))
//         }
//         await vPage.close()
//         await vBrowser.close()
//     } catch (error) {
//         sig.error(error)
//     } finally {
//         process.exit(0)
//     }
// }
// clip()
// import csstree from 'css-tree'

// const parsed = csstree.parse('@import url("s")')
// console.log(parsed)
import { readdirSync, statSync } from 'fs-extra'
import { ClipOptionsWithURL, VBrowser } from './core/VBrowser'

async function main() {
    const files = [] as ClipOptionsWithURL[]

    const dirs = readdirSync('g:/clips').filter(
        f => statSync('g:/clips/' + f).isDirectory() && f === 'life'
    )

    dirs.forEach(d => {
        files.push(
            ...readdirSync('g:/clips/' + d).map(f => ({
                url: `file:///g:/clips/${d}/${f}`,
                maxScrolls: 0,
                outputPath: `.vanilla-clipper/pages/${d}/${f}`,
            }))
        )
    })

    await VBrowser.clipPages({ noSandbox: false, headless: true }, files)
}

main()
